//@charset "utf-8";
/*********************************************************
 文件: imengine.js
 作者: 何玮<away@myhexin.com>
 创建: 2009-12-22
 用途: 即时通讯程序接口引擎.
 历史:
 2009-12-31    增加了从url参数中获取聊天对象imid，并对收发数据
 进行了限制
 补充了部分注释。
 *********************************************************/
// 测试环境使用"account"
// 正式环境使用"msgcode"
KEY_IMID = 'msgcode';

if (Config.isWebClient) {
    thsPassport = false;
}

// 用于Web方式下截屏后生成的图片名与图片数据的对应表
ImgCache = {};

// 即时通讯数据处理对象
IMHandler = Class.extend({

    /**
     * 用于生成请求包唯一ID的前缀
     *
     * @type    String
     */
    _idPrefix: ('im_' + (new Date()).getTime() + '_')    /**
     * 用于生成请求包唯一ID的后缀
     *
     * @type    Number
     */
    ,
    _packageId: 0    /**
     * 当前用户的imid
     *
     * @type    String
     */
    ,
    _imid: (thsPassport ? thsPassport.get(KEY_IMID) : Ext.util.Cookies.get(KEY_IMID)) || href.getParam('selfId')    /**
     * 当前用户的名字
     *
     * @type    String
     */
    ,
    _name: href.getParam('name')// || Ext.util.Cookies.get(Config.userNameCookieId)
    /**
     * 当前用户的类型：1、普通用户；2、经纪人；3、客服人员；
     *
     * @type    String
     */
    ,
    _type: href.getParam('type')// || Ext.util.Cookies.get(Config.userTypeCookieId)
    /**
     * 当前用户的状态：1、在线；    2、忙碌；  3、离线；
     *
     * @type    String
     */
    ,
    _status: href.getParam('status', 'online'),
    _vimid: null    /**
     * 聊天对象的imid
     *
     * @type    String
     */
    ,
    _toimid: href.getParam('imid')    /**
     * 聊天对象的用户类型
     *
     * @type    String
     */
    ,
    _toType: href.getParam('toType')    /**
     * 一些必须主动请求的请求时间间隔
     *
     * @type    Number
     */
    ,
    _autoRequestT: 5000    /**
     * 请求包缓存池
     *
     * @type    Array
     */
    ,
    _packages: null    /**
     * 请求数据最长超时时间，默认9999毫秒
     *
     * @type    Number
     */
    ,
    _timeout: 9999    /**
     * 轮询请求包缓冲池的操作时间间隔
     *
     * @type    Number
     */
    ,
    _polltime: 3500    /**
     * 所有与当前用户接触过的聊天对象
     *
     * @type    Array
     */
    ,
    _toimids: null,
    _chatForUserType: 'N'    /**
     * 构造函数，初始化操作
     *
     * @param {IMClient}        client         客户端接口对象
     * @param {IMController}    controller     视图对象
     */
    ,
    init: function(client, controller){
        this._packages = [];
        this._toimids = [];
        this._nonOffline = [];
        this._firstGetMsg = true;
        this._client = client;
        this._controller = controller;
        
        
        var self = this;
        
    }    /**
     * 析构函数，用于释放内存
     */
    ,
    destroy: function(){
        this._client = null;
        this._controller = null;
        this._packages = null;
        this._toimids = null;
    },
    clearData: function(userImid){
        if (userImid == this._toimid) {
            return;
        }
        for (var i = 0, len = this._toimids.length; i < len; ++i) {
            if (this._toimids[i] == userImid) {
                delete this._toimids[i];
                break;
            }
        }
        this._controller.onClearData(userImid);
    }    /**
     
     * 设置请求包生成唯一ID的前缀
     *
     * @param {String}  idPrefix    指定的前缀名称
     */
    ,
    setIdPrefix: function(idPrefix){
        this._idPrefix = idPrefix + '_' + (new Date()).getTime() + '_';
    },
    
    hasSelfImid: function(){
        return !Ext.isEmpty(this._imid);
    },
    setDomain: function(domain){
        this._domain = domain;
    },
    getDomain: function(){
        return this._domain;
    }    /**
     * 获取当前用户的客户号
     *
     * @return {String}
     */
    ,
    getSelfImid: function(){
        return this._imid;
    }    /**
     * 用于设置自身的客户号
     *
     * @param {String}  imid    所需设定的自身的客户号
     */
    ,
    setSelfImid: function(imid){
        this._imid = imid;
    }    /**
     * 获取当前聊天对象的的客户号
     *
     * @return {String}
     */
    ,
    getToImid: function(){
        return this._toimid;
    }    /**
     * 用于设置当前聊天对象的客户号
     *
     * @param {String} toimid   所需设定的聊天对象的客户号
     */
    ,
    setToImid: function(toimid){
        this._toimid = toimid;
        this._controller.setViewToImid(toimid);
    }    /**
    
     * 获取当前聊天对象的的用户类型
    
     *
    
     * @return {String}
    
     */
    
    ,
    
    isSelf: function(imid){
        return this._imid == imid;
    }    /**
     * 判断所传入的客户号是否就是当前聊天对方的客户号
     *
     * @param   {String}    toimid  所需判断的客户号
     * @return  {boolean}
     */
    ,
    isOther: function(toimid){
        return this._toimid == toimid;
    },
    
    
    setSignature: function(param, signature, other){
        if (!signature) {
            signature = "";
            //			return;
        }
        signature = signature.replace(/&/g, '&amp;');
        signature = signature.replace(/</g, '&amp;lt;');
        var nickname = other.nickname;
        nickname = nickname.replace(/&/g, '&amp;');
        nickname = nickname.replace(/</g, '&amp;lt;');
        
        //		xmlText = xmlText.replace(/&/g,'&amp;');
        //									xmlText = xmlText.replace(/<BR>/g,'&lt;BR&gt;').replace('/</g','&lt;');
        var vcard = [];
        var flag = false;
        var vcard = [];
        vcard.push('<iq id="8" type="set"> ');
        vcard.push('<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">');
        vcard.push('<NICKNAME>', nickname, '</NICKNAME>');
        vcard.push('<BDAY>', param.birthday, '</BDAY>');
        vcard.push('<REGION>', param.region, '</REGION>');
        vcard.push('<CITY>', param.city, '</CITY>');
        vcard.push('<X-SIGNATURE>', signature, '</X-SIGNATURE>');
        vcard.push('<X-SEX>', param.sex, '</X-SEX>');
        vcard.push('<X-AGE>', param.age, '</X-AGE>');
        vcard.push('<X-HEADIMAGE>0</X-HEADIMAGE>');
        vcard.push('<X-ALLOW>', param.x_allow, '</X-ALLOW>');
        vcard.push('<X-SHENGXIAO>', param.sx, '</X-SHENGXIAO>');
        vcard.push('<X-BLOODGROUP>', param.bloodType, '</X-BLOODGROUP>');
        vcard.push('<X-ACCOUNT>', param.account, '</X-ACCOUNT>');
        vcard.push('</vCard>');
        vcard.push('</iq>');
        
        vcard = vcard.join('');
        
        
        this.setUserVcard(vcard);
    },
	
	//发送正在看盘股友请求
	 sendKP: function(userid,code){
        var selfImid = this._imid;
        
        
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
		
       var content = '<iq type="get" to="stockrelation.glt" from="'+userid+'@hexin.glt">'+
					  '<query xmlns="jabber:iq:getstockuser" stockcode="'+code+'"/>'+
					  '</iq>';
	   	var request = new IMRequest(content);
	   	this.sendRequest(request);
    },
    
	sendRecentNotNotice : function(data){
		var selfImid = this._imid;
		if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
		 
		if(data.op =="open"){
			//<iq type="set" op="msgremind"><query xmlns="jabber:iq:msgnoremind"/><x gltcode="23434456"></iq> 

			var content = '<iq type="set"  op="msgremind">'+
					  '<query xmlns="jabber:iq:msgnoremind" />'+'<x gltcode="'+selfImid+'"/>'+
					  '</iq>';
		}else if(data.op=="close"){
			var content = '<iq type="set"  op="msgremind">'+
					  '<query xmlns="jabber:iq:msgremind" />'+'<x gltcode="'+selfImid+'"/>'+
					  '</iq>';
		}else{
			return;
		}
		
		var request = new IMRequest(content);
	   	this.sendRequest(request);
	},
	
    //发送群组消息
    sendGroupMsg: function(data, obj){
        var selfImid = this._imid;
        
        
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var msg = [];
        var flag = false;
        
        if (data && data.type && data.type == 'capture') {
            var test = data.html;
            msg.push('<message type="groupchat" to="', data.toimid, '@group.hexin.glt"  from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;text> &lt;/text>&lt;/span>&lt;/body></html>', '</message>');
            flag = true;
        }
        else {
            var test = data.html;
            //test = "<test>fdsafl          范德萨                      </test>";
            msg.push('<message type="groupchat" to="', data.toimid, '@group.hexin.glt"  from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;/span>&lt;/body></html>', '</message>');
        }
        msg = msg.join('');
        var request = new IMRequest(msg);
        this.sendRequest(request);
        if (flag) {
        
            this.sendGroupFile(data);
        }
    },
    //群文件发送一些列协议
    sendGroupFileHandle: function(data){
        var selfImid = this._imid;
        
        
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var msg = [];
        switch (data.action) {
            case "finish":
                //				<message type="groupchat" to="111@group.hexin.glt" from="1035@hexin.glt">	
                //     <file xmlns="jabber:iq:file" id="jsi_7300111378517517279" digest="568bc69041d7507d72c8570fff855b5c" name="test.html" type="" size="451" token="880aea7bf20ab5780b48f56a88786af56a25f2ea886a78adadadea88887b88f2" action="finish">	
                //		 <streamhost host="10.0.1.120" port="9700"/>
                //	 </file>
                // </message>
                msg.push('<message type="groupchat" to="', data.toImid, '@group.hexin.glt" from="', selfImid, '@hexin.glt">', '<file xmlns="jabber:iq:file" id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="img" size="', data.fileSize, '" token="', data.token, '" action="finish">', '</file>', '</message>');
                
                break;
            case "send":
                break;
        }
        var request = new IMRequest(msg.join(''));
        this.sendRequest(request);
        
        
    },
    //群文件发送
    sendGroupFile: function(data){
        //		<message type="groupchat" to="111@group.hexin.glt" from="1035@hexin.glt">	
        //     <file xmlns="jabber:iq:file" id="jsi_7300111378517517279" digest="568bc69041d7507d72c8570fff855b5c" name="test.html" type="" size="451"/>		
        // </message>
        
        
        
        var fileMsg = [];
        var self = this;
        if (data && data.type && data.type == 'capture') {
            $.each(data.captureObjs, function(){
                fileMsg = [];
                fileMsg.push('<message type="groupchat" to="', data.toimid, '@group.hexin.glt">', '<file xmlns="jabber:iq:file" action="', data.captureType, '"  id="', this.captureId, '" digest="', this.capDigest, '" name="', this.captureId, '" type="img" size="', this.captureSize, '"/>', '</message>');
                
                fileMsg = fileMsg.join('');
                var request = new IMRequest(fileMsg);
                self.sendRequest(request);
                
            });
            
            return;
            
        }
        else {
            fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="send"  id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="" size="', data.fileSize, '"/>', '</message>');
            
            
        }
        
        
        fileMsg = fileMsg.join('');
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    //加好友协议
    sendAddFriendList: function(data){
        var xy = '<iq id="3" type="get" to="' + data.imid + '@hexin.glt">';
        xy += '<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">';
        xy += '<X-NEW>1</X-NEW>';
        xy += '</vCard>';
        xy += '</iq>';
        
        var request = new IMRequest(xy);
        this.sendRequest(request);
    },
    
    //一系列的群组协议
    groupProtocalHandle: function(data){
        var msg = [];
        var selfImid = this._imid;
        
        
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        
        
        
        switch (data.action) {
            case "create":
                var name = data.name;
                var jointype = data.jointype;
                var desc = data.desc;
                var affiche = data.affiche;
                var owneraccout = data.account;
                var ownernick = data.nick;
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#create">', '<group name="', name, '" category="" subcategory="" jointype="', jointype, '" search="" owner_account="', owneraccout, '" owner_nick="', ownernick, '">', '<desc><![CDATA[', desc, ']]></desc>', '<affiche><![CDATA[', affiche, ']]></affiche>', '</group>', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case "getGroupList":
                
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="group.hexin.glt" type="get">', '<query xmlns="jabber:iq:muc#groups"/>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                
                break;
            case 'destory':
                var groupid = data.groupId;
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#destory">', '<group jid="', groupid, '@group.hexin.glt"/>', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'quit':
                var groupid = data.groupId;
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#withdraw" />', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'search':
                if (data.flag == "groupid") {
                    var groupid = data.groupId;
                    msg.push('<iq from="', selfImid, '@hexin.glt"  to="group.hexin.glt" type="get">', '<query xmlns="jabber:iq:muc#search">', '<field type="id" cond="', groupid, '" />', '</query>', '</iq>');
                    
                }
                else 
                    if (data.flag == "name") {
                        var name = data.name;
                        msg.push('<iq from="', selfImid, '@hexin.glt"  to="group.hexin.glt" type="get">', '<query xmlns="jabber:iq:muc#search">', '<field type="name" cond="', name, '" />', '</query>', '</iq>');
                        
                    }
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'apply':
                var userid = data.userid;
                var tempMsg = data.msg;
                var groupid = data.groupid;
                var nick = data.nick;
                msg.push('<message from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="group">', '<x xmlns="jabber:iq:muc#apply">', '<apply account="', userid, '"  msg="', tempMsg, '" nick="', nick, '"/>', '</x>', '</message>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'inivate':
                var checkObj = data.checkObj;
                msg.push('<iq from="' + selfImid + '@hexin.glt"  to="' + data.groupID + '@group.hexin.glt" type="set"> ');
                msg.push('<x xmlns="jabber:iq:muc#invite">');
                $.each(checkObj, function(key, val){
                    msg.push('<user jid="' + val['imid'] + '@hexin.glt"/>');
                });
                msg.push('</x>');
                msg.push('</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'getGroupInfo':
                msg.push('<iq id="5" from="' + selfImid + '@hexin.glt" to="' + data.groupId + '@group.hexin.glt" type="get">');
                msg.push('		<query xmlns="jabber:iq:muc#groupinfo" />');
                msg.push('</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'getGroupNick':
                msg.push('<iq from="' + selfImid + '@hexin.glt" to="' + data.groupId + '@group.hexin.glt" type="get">');
                msg.push('	<query xmlns="jabber:iq:muc#nick" >');
                msg.push(' 		<user jid="' + data.jid + '@hexin.glt" /> ');
                msg.push('</query>');
                msg.push('</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'agreeIn':
                //管理员同意。。加入
                var imid = data.imid;
                var groupid = data.groupid;
                var groupname = data.groupname;
                var account = data.name;
                var nick = data.nick;
                
                
                msg.push('<message from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="group">', '<x xmlns="jabber:iq:muc#apply">', '<response user_jid="', imid, '@hexin.glt" group_name="', groupname, '" action="agree" account="', account, '" nick="', nick, '"/>', '</x>', '</message>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'refuseIn':
                var imid = data.imid;
                var groupid = data.groupid;
                var groupname = data.groupname;
                
                msg.push('<message from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="group">', '<x xmlns="jabber:iq:muc#apply">', '<response user_jid="', imid, '@hexin.glt" group_name="', groupname, '" action="decline" />', '</x>', '</message>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                
            case "getUsers":
                
                
                var groupid = data.imid;
                
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="get">', '<query xmlns="jabber:iq:muc#users" />', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'setGroupInfo':
                msg.push(' <iq id="6" from="' + selfImid + '@hexin.glt"  to="' + data.groupid + '@group.hexin.glt" type="set" > ');
                msg.push('  <x xmlns="jabber:iq:muc#groupinfo"> ');
                msg.push('  <group name="' + data.groupname + '" category="" subcategory="" jointype="' + data.jointype + '" search="">');
                msg.push('  	<desc><![CDATA[', data.desc, ']]></desc> ');
                msg.push(' 		<affiche><![CDATA[', data.affiche, ']]></affiche>  ');
                msg.push('  </group>  ');
                msg.push(' </x> ');
                msg.push(' </iq> ');
                
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
                
            case 'setGroupNick':
                
                
                
                msg.push(' <iq from="' + selfImid + '@hexin.glt" to="' + data.groupid + '@group.hexin.glt" type="set" >');
                msg.push('  <x xmlns="jabber:iq:muc#nick"> ');
                msg.push('      <user jid="', data.jid, '@hexin.glt"  nick="' + data.nick + '"  contact="' + data.contact + '"  desc="' + data.desc + '"  /> ');
                msg.push(' </x> ');
                msg.push(' </iq> ');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case "agreeInviteIn":
                var groupid = data.groupid;
                //				var nick = data.nick;
                //				var account = data.account;
                //                <iq from='96735603@hexin.glt' id='create1' to='111@group.hexin.glt' type='set'>
                //	<x xmlns='jabber:iq:muc#invite'>
                //		<response action="agree" account="" nick="">
                //	</x>
                //</iq>
                
                
                msg.push('<iq from="', selfImid, '@hexin.glt"  to="', groupid, '@group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#invite" >', '<response action="agree" account="', data.account, '" nick="', data.nick, '" />', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'getUserInfo':
                var toImid = data.imid;
                var groupid = data.groupid;
                msg.push('<iq id="', groupid, '" type="get" to="', toImid, '@hexin.glt"><vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0"></vCard></iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'menu_setadmin'://设为管理员
                var toImid = data.imid;
                var groupid = data.groupid;
                msg.push('<iq from="', selfImid, '@hexin.glt"   to="', groupid, '@group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#setrole">', '<user jid="', toImid, '@hexin.glt" role="admin"/>', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
            case 'menu_deladmin':
                var toImid = data.imid;
                var groupid = data.groupid;
                msg.push('<iq from="', selfImid, '@hexin.glt"   to="', groupid, '@group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#setrole">', '<user jid="', toImid, '@hexin.glt" role="member"/>', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
            case 'menu_deluser':
                var toImid = data.imid;
                var groupid = data.groupid;
                msg.push('<iq from="', selfImid, '@hexin.glt"   to="', groupid, '@group.hexin.glt" type="set">', '<x xmlns="jabber:iq:muc#kick">', '<user jid="', toImid, '@hexin.glt" />', '</x>', '</iq>');
                msg = msg.join('');
                var request = new IMRequest(msg);
                this.sendRequest(request);
                break;
        }
        
        //		<iq from='96735603@hexin.glt' id='create1' to='111@group.hexin.glt' type='set'>
        //	<x xmlns='jabber:iq:muc#kick'>
        //		<user jid=""/>
        //	</x>
        //</iq>
    
        //	<iq from='96735603@hexin.glt' id='create1' to='111@group.hexin.glt' type='set'>
        //	<x xmlns='jabber:iq:muc#setrole'>
        //		<user jid="" role="admin/member"/>
        //	</x>
        //</iq>
    },
    
    
    //重置昵称协议
    resetNickName: function(){
        var vcard = [];
        vcard.push('<iq id="8" type="set"> ');
        vcard.push('<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">');
        vcard.push('<NICKNAME></NICKNAME>');
        vcard.push('<BDAY></BDAY>');
        vcard.push('<REGION></REGION>');
        vcard.push('<CITY></CITY>');
        vcard.push('<X-SIGNATURE></X-SIGNATURE>');
        vcard.push('<X-SEX></X-SEX>');
        vcard.push('<X-AGE></X-AGE>');
        vcard.push('<X-HEADIMAGE></X-HEADIMAGE>');
        vcard.push('<X-ALLOW></X-ALLOW>');
        vcard.push('<X-SHENGXIAO></X-SHENGXIAO>');
        vcard.push('<X-BLOODGROUP></X-BLOODGROUP>');
        vcard.push('<X-ACCOUNT></X-ACCOUNT>');
        vcard.push('</vCard>');
        vcard.push('</iq>');
        
        vcard = vcard.join('');
        
        
        this.setUserVcard(vcard);
    },
    //设置个人信息
    setUserVcard: function(param){
        var request = new IMRequest(param);
        this.sendRequest(request);
        
        
        this.getUserInfo();
    },
    //设置昵称
    setNickName: function(nickname, other){
        if (!nickname) {
            return;
        }
        
        nickname = nickname.replace(/&/g, '&amp;');
        nickname = nickname.replace(/</g, '&amp;lt;');
        var signature = other.signature;
        signature = signature.replace(/&/g, '&amp;');
        signature = signature.replace(/</g, '&amp;lt;');
        var vcard = [];
        var flag = false;
        vcard.push('<iq id="29" type="set">', '<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">', '<NICKNAME>', nickname, '</NICKNAME>', '<x-signature>', signature, '</x-signature>', '</vCard></iq>');
        vcard = vcard.join('');
        
        var request = new IMRequest(vcard);
        this.sendRequest(request);
    },
    
    //加好友是否需要验证
    ifNeedJustFy: function(xmlStr){
        try {
            var imid = xmlStr.split('@')[0];
            var GroupName = Config.userGroupMap.get(imid);
            if (GroupName == 'myfriend') {
                //已经是好友了 提示
                var param = {
                    'url': thsUtil.getProgramPath() + 'addFriendTip.html?imid=' + imid,
                    'title': '提示',
                    'cx': 300,
                    'cy': 150,
                    'id': "addFTip"
                };
                
                thsIM.openNewWindow(param);
                
            }
            else {
                //发送协议
                
                var xy = '<iq id="3" type="get" to="' + imid + '@hexin.glt">';
                xy += '<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">';
                xy += '<X-NEW>1</X-NEW>';
                xy += '</vCard>';
                xy += '</iq>';
                
                
                var request = new IMRequest(xy);
                this.sendRequest(request);
            }
            
        } 
        catch (e) {
        }
        
        
        
        
    },
    //发送删除好友协议
    sendDeleteUserPrce: function(data){
        var msg = [];
        var flag = false;
        msg.push('<presence to="' + data.toImid + '@hexin.glt" from="' + this._imid + '@hexin.glt" type="unsubscribe"></presence>');
        msg = msg.join('');
        var request = new IMRequest(msg);
        this.sendRequest(request);
		
		thsCache.callFunction({
			'name' : 'unFollow',
			'param': data.uid
		});
    },
    
    //服务器返回的IQ协议通知，主要是好友列表，请求请求好友等通知
    iqHandle: function(xmlDoc){
        var $root = $(xmlDoc.documentElement);
        var NS = $($root.children()).attr('xmlns');
        if (!NS) {
            return;
        }
        switch (NS) {
            case NameSpace.roster:
                if ($root.attr('type') === 'result' && $root.attr('type')) {
                    var $item = $root.find('item');
                    var data = [];
                    this.getPresence();
//                    this.groupProtocalHandle({
//                        action: "getGroupList"
//                    });
                    try {
                        this._controller.onGetUserList($item);
                    } 
                    catch (e) {
                    }
                    
                    Config.userThsAccount = '';
                    
                //                    $.ajax({
                //                        type: 'GET',
                //                        url: 'http://172.20.0.188:5090/mail/find.php?type=get&gltno=' + this._imid,
                //                        async: false,
                //                        success: function(data){
                //                            data = data.substring(data.indexOf('=') + 1, data.length - 1);
                //                            
                //                            Config.userThsAccount = data;
                //                        },
                //                        failure: function(){
                //                        },
                //                        dataType: 'JSON'
                //                    });
                }
                if ($root.attr('type') && $root.attr('type') == 'set') {
                    var $item = $root.find('item');
                    this._controller.onAddFriend($item);
                }
                
                //test
                break;
			
			case NameSpace.geStockuser:
				  if ($root.attr('type') && $root.attr('type') == 'result') {
                    var count = $root.find('count').text();
					var uid = $root.find('uid').text();
					thsCache.callFunction({
						'name' : 'getStockUser',
						'param' : {'count' : count,'uid':uid}
					});
                    
                }
                    
				break;
			
            case NameSpace.vcard:
                if (!$root.attr('from')) 
                    return;
                
                
                var id = $root.attr('id');
				var userid = $root.find("USERID").text();
                var showname = $root.find("nickname").text();
                var avatar = $root.find("AVATAR").text();
                var signature = $root.find('X-SIGNATURE').text();
                var account = $root.find("X-ACCOUNT").text();
                var birthday = $root.find('BDAY').text();
                var sex = $root.find('X-SEX').text();
                var x_allow = $root.find('X-ALLOW').text();
                var age = $root.find('X-AGE').text();
                var sx = $root.find('X-SHENGXIAO').text();
                var bloodType = $root.find('X-BLOODGROUP').text();
                var region = $root.find('REGION').text();
                var city = $root.find('CITY').text();
                var from = $root.attr('from');
                if (!showname) {
                    if (from.indexOf("/") > -1) {
                    }
                    showname = from.substring(from.lastIndexOf("/") + 1, from.length);
                }
                thsCache.setValue('selfInfo', from);
                data = {
                    imid: from,
                    name: showname,
                    avatar: avatar,
                    signature: signature,
                    sex: sex,
					userid: userid,
                    x_allow: x_allow,
                    account: account,
                    birthday: birthday,
                    age: age,
                    sx: sx,
                    bloodType: bloodType,
                    region: region,
                    city: city
                }
                if (id.length > 1) {
                    var groupid = id;
                    thsCache.callFunction({
                        'name': "getGroupCheckUserInfo" + groupid,
                        'param': data
                    });
                
                
                
                }
                else {
                    this._controller.onGetUserInfo(data);
                }
                
                
                break;
            case NameSpace.group:
                
                var action = $($root.children()).attr("action");
                
                
                var $bindGroup = $root.find('bindgroup');
                
                var $user = $root.find('user');
                if (action == "getbindgroup") {
                
                    this._controller.onGetGroupList($bindGroup);
                    
                    
                }
                else 
                    if (action == "getbindgroupuser") {
                        var jid = $bindGroup.attr('jid');
                        
                        if (jid && jid.indexOf('@') > -1) {
                            jid = jid.split('@')[0];
                        }
                        this._controller.onGetGroupUserList($user, jid);
                    }
                break;
            case NameSpace.auth:
                break;
            case "jabber:iq:updateserv":
                
                
                var group = $($root.children()).attr('group');
                var data = {
                    item: $root.find('item'),
                    group: group
                }
                
                
                this._controller.onChangeGroupUserList(data);
                break;
            case GroupNameSpace.create:
                //				var from = $root.attr('from');
                var $group = $root.find('group');
                if ($group && $group.attr('jid')) {
                    var name = $group.attr('name');
                    var groupId = $group.attr('jid');
                    var desc = $group.attr('desc');
                    var jointype = $group.attr('jointype');
                    var maxusers = $group.attr('maxusers');
                    var data = {
                        name: name,
                        groupId: groupId,
                        desc: desc,
                        jointype: jointype,
                        maxusers: maxusers,
                        type: "createGroupSuccess"
                    }
                    this._controller.onCreateGroup(data);
                    
                }
                else 
                    if ($root.find('error') && $root.find('error').attr('auth')) {
                        var msg = $root.find('error').attr('msg');
                        var data = {
                            msg: msg,
                            type: "createGroupFail"
                        }
                        this._controller.onCreateGroup(data);
                    }
                    else {
                    //do nothing...
                    }
                break;
            case GroupNameSpace.getGroups:
                
                var group = $root.find('group');
                this._controller.onGetGroupList(group);
                break;
            case GroupNameSpace.destroy:
                var group = $root.find('group');
                this._controller.onDestroyGroup(group);
                break;
            case GroupNameSpace.quit:
                var type = $root.attr('type');
                var from = $root.attr('from');
                from = from.substring(0, from.indexOf('@'));
                
                
                if (type && type == "result") {
                    this._controller.onQuitGroup(from);
                }
                else 
                    if (type && type == "set") {
                        $user = $root.find('user');
                        var anoImid = $user.attr('jid');
                        anoImid = anoImid.substring(0, anoImid.indexOf('@'));
                        
                        this._controller.onQuitAnoGroup({
                            from: from,
                            anoImid: anoImid
                        });
                    }
                
                
                
                var group = $root.find('user');
                this._controller.onQuitGroup(group);
                break;
            case GroupNameSpace.search:
                var group = $root.find('group');
                this._controller.onSearchGroup(group);
                break;
            case GroupNameSpace.join:
                var from = $root.attr('from');
                from = from.substring(0, from.indexOf('@'));
                var user = $root.find('user');
                
                var group = $root.find('group');
                if (user && user.attr('jid')) {
                
                    var userid = user.attr('jid');
                    userid = userid.substring(0, userid.indexOf('@'));
                    var account = user.attr('account');
                    var nick = user.attr('nick');
                    this._controller.onNoticeJoinGroup({
                        userid: userid,
                        from: from,
                        account: account,
                        nick: nick
                    });
                    
                    
                    
                }
                else 
                    if (group && group.attr('jid')) {
                        this._controller.onAgreeJoinGroup(group);
                    }
                
                
                break;
            case GroupNameSpace.users:
                var groupid = $root.attr('from');
                groupid = groupid.substring(0, groupid.indexOf('@'));
                var $user = $root.find('user');
                //				var userImid = $user.attr('jid');
                //				userImid = userImid.substring(0, userImid.indexOf('@'));
                //				
                //				
                //				var account = $user.attr('account');
                //				var nick = $user.attr('nick');
                //				var role = $user.attr('role');
                //				var presence = $user.attr('presence');
                //				
                //				var data ={
                //					groupid : groupid,
                //					imid : userImid,
                //					account :account,
                //					nick :nick,
                //					role: role,
                //					presence:presence
                //				}
                this._controller.onGetGroupUserList($user, groupid);
                break;
            case GroupNameSpace.groupinfo: //获取群信息
                var id = $root.attr('id');
                
                if (id == 5) {
                    this._controller.onGetGroupInfo($root);
                }
                else 
                    if (id == 6) {
                        this._controller.onSetGroupInfo($root);
                    }
                    else {
                        this._controller.onGetGroupInfo($root);
                    }
                
                
                break;
            case GroupNameSpace.nick: //获取群名片
                var type = $root.attr('type');
                if (type == "get") {
                
                
                    this._controller.onGetGroupNick($root);
                }
                else 
                    if (type = "result") {
                    
                        var groupid = $root.attr('from');
                        groupid = groupid.substring(0, groupid.indexOf('@'));
                        var $user = $root.find('user');
                        var userid = $user.attr('jid');
                        if (userid) {
                            userid = userid.substring(0, userid.indexOf('@'));
                        }
                        var nick = $user.attr('nick');
                        
                        
                        this._controller.onChangeNick({
                            groupid: groupid,
                            userid: userid,
                            nick: nick
                        });
                    }
                break;
            case GroupNameSpace.setrole:
                var type = $root.attr('type');
                if (type == 'result' || type == 'set') {
                    var groupid = $root.attr('from');
                    groupid = groupid.substring(0, groupid.indexOf('@'));
                    var $user = $root.find('user');
                    var userid = $user.attr('jid');
                    if (userid) {
                        userid = userid.substring(0, userid.indexOf('@'));
                    }
                    var role = $user.attr('role');
                    this._controller.onSetRole({
                        groupid: groupid,
                        userid: userid,
                        role: role
                    });
                    
                }
                break;
            case GroupNameSpace.kick:
                
                
                var type = $root.attr('type');
                if (type == 'result' || type == 'set') {
                    var groupid = $root.attr('from');
                    groupid = groupid.substring(0, groupid.indexOf('@'));
                    var $user = $root.find('user');
                    var userid = $user.attr('jid');
                    if (userid) {
                        userid = userid.substring(0, userid.indexOf('@'));
                    }
                    this._controller.onKickuser({
                        groupid: groupid,
                        userid: userid
                    });
                    
                }
                
                break;
			case NameSpace.getuserid :
				var user = $root.find('user');
				this._controller.ongetImidByUserid({
					userid : user.attr('userid'),
					imid : user.attr('gltcode')
				})
				break;
			case NameSpace.getotherinfo:
			
				var user = $root.find('user');
				var op =  $root.attr('op');
				if(op == "userid"){
					var imid = user.attr('gltcode');
					var status = user.attr('status');
					var userid = user.attr('userid');
					this._controller.ongetImidByUserid({
						userid : userid,
						imid : imid,
						status : status
					})
				}else if(op == "gltcode"){
					var name = user.attr('NICKNAME');
					var imid = user.attr('gltcode');
					var status = user.attr('status');
					var userid = user.attr('userid');
					
					this._controller.ongetotherinfo({
						userid : userid,
						imid : imid,
						status : status,
						nickname : name
					})
				}
				
				break;
        }
    },
    
	//行情点击粉丝消息 和系统消息回调
	sysAndFensiMsgCallback : function(data){
		this._controller.sysAndFensiMsgCallback(data);
	},
	//论股弹。。。
	theoryStockCallback : function(data){
		var xmlDoc = new ActiveXObject('MSXML2.DOMDocument.3.0');
        xmlDoc.async = false;
		if (xmlDoc.loadXML(data)) {
			var $root = $(xmlDoc.documentElement);
			var url = $root.find('msg_node').attr('val');
			if(url){
				this._controller.BtheoryStockCallback(url); 
			}
		}
	},
	
	getTookenCallback : function(data){
		var xmlDoc = new ActiveXObject('MSXML2.DOMDocument.3.0');
		        xmlDoc.async = false;
		if (xmlDoc.loadXML(data)) {
			 var $root = $(xmlDoc.documentElement);
			 var token = $root.find('msg_node').attr('token');
			if(token){
				thsCache.callFunction({
					'name' : "getMyFollowUrl",
					'param' : token
				})
			}
		}
	},
	
    //发送自动签收协议
    sendAutoSign: function(from, isDelayS, id){
    
        var status = 1;
        if (isDelayS) {
            status = 0;
        }
        var msg = [];
        var flag = false;
        msg.push('<message type="receipt" to="', from, '" status = "', status, '" id="', id, '"></message>');
        msg = msg.join('');
        var request = new IMRequest(msg);
        this.sendRequest(request);
        
    },
    
    //发送已经阅读协议
    sendIsReaded: function(data){
        var id = data.id;
        var from = data.from;
        if (from.indexOf('@') > -1) {
            from = from;
        }
        else {
            from = from + "@hexin.glt";
        }
        var status = data.status;
        var msg = [];
        var flag = false;
        msg.push('<message type="readed" to="', from, '" status = "', status, '" id="', id, '"></message>');
        msg = msg.join('');
        var request = new IMRequest(msg);
        this.sendRequest(request);
    },
    //保存消息记录到本地文件
    _saveAnotherRecords: function(from, to, data,timeStamp){
		if(timeStamp){
			var time = timeStamp;
			time = time / 1000;
		}else{
			var time = Date.parse(new Date());
       	 	time = time / 1000;
		}
       
        
        var body = "<html><body>" + data + "</body></html>";
        var result = thsIM.writeMsgRecord({
            'to': to,
            'time': time,
            'from': from,
            'body': body
        });
		
    },
    
    //群消息保存本地文件
    _saveAnotherRecords1: function(groupid, from, to, data){
        var time = Date.parse(new Date());
        time = time / 1000;
        
        var body = "<html><body>" + data + "</body></html>";
        var result = thsIM.writeMsgRecord({
            'to': to,
            'time': time,
            'from': from,
            'body': body,
            'groupid': groupid
        });
    },
    
	convertStampTodate : function(str){
		var year = str.substring(0,4);
		var month =str.substring(4,6)
		if(month.substring(0,1) == 0){
			month =month.substring(1,2);
		}
		month = parseInt(month)- 1;
		var day = str.substring(6,8);
		if(day.substring(0,1) == 0){
			day =day.substring(1,2);
		}
		var hour = str.substring(9,11);
		if(hour.substring(0,1) == 0){
			hour =hour.substring(1,2);
		}
		var minute = str.substring(12,14);
		if(minute.substring(0,1) == 0){
			minute =minute.substring(1,2);
		}
		var second = str.substring(15,17);
		if(second.substring(0,1) == 0){
			second =second.substring(1,2);
		}
		return {
			year :parseInt(year),
			month :parseInt(month),
			day :parseInt(day),
			hour : parseInt(hour),
			minute :parseInt(minute),
			second :parseInt(second)
		}
	},
	
    //客户端message协议通知  主要包括 收到好友等聊天消息包括截图传文件等
    msgHandle: function(xmlDoc){
        var root = xmlDoc.documentElement;
//        $(root).find('span').length;1;2;
        var $root = $(xmlDoc.documentElement);
        var type = $root.attr('type');
        var autoSign = $(root).find("reqreceipt");
        var from = $root.attr('from');
        var NS = $($root.children()).attr('xmlns');
		
		
		
        var id = $root.attr('id');
        var isDelayS = false;
        var isDelay = $root.find('x');
        var isNeedAutoSign = false;
        
        if (isDelay && isDelay.attr('xmlns') == "jabber:x:delay") {
            isDelayS = true;
        }
        if (!type) {
            return;
        }
		
		
        var data = {};
        var tempCaptureFlag = '';
        if (autoSign && autoSign.text() == "reqreceipt") {
            isNeedAutoSign = true;
            this.sendAutoSign(from, isDelayS, id);
        }
        
        if (type == 'chat') {
			var nameSpace = $root.find('x').attr('xmlns');
            if ($(root).find('kjyx').get(0)) {
                var tempBody = $(root).find('body').text();
                this._controller.onGetKjyxMsg(tempBody);
                return;
            }
            
            
            var selfImid = this._imid;
            if (selfImid && selfImid.indexOf('=') > -1) {
                selfImid = selfImid.split('=')[1];
            }
            
            from = from.substring(0, from.indexOf('@'));
             if (nameSpace == "jabber:x:delay") {
			 	
				var stamp = isDelay.attr("stamp");
				var sdate = this.convertStampTodate(stamp);
				timeStamp2 = new Date(sdate.year,sdate.month,sdate.day,sdate.hour,sdate.minute,sdate.second).getTime();
				
			 	if ($(root).find('html').get(0)) {
				
	                this._saveAnotherRecords(from, selfImid, $(root).find('html').get(0).xml,timeStamp2);
		            }
		            else {
		                var tempBody = $(root).find('body').text();
		                tempBody = "<span><text>" + tempBody + "</text></span>"
		                this._saveAnotherRecords(from, selfImid, tempBody,timeStamp2);
		            }
			 }else{
			 	if ($(root).find('html').get(0)) {
	                this._saveAnotherRecords(from, selfImid, $(root).find('html').get(0).xml);
	            }
	            else {
	                var tempBody = $(root).find('body').text();
	                tempBody = "<span><text>" + tempBody + "</text></span>"
	                this._saveAnotherRecords(from, selfImid, tempBody);
	            }
			 }
            
            Config.tempStr = '';
            var context = XmlFileOperator.parseTool($root.find('span'), $root);
		
			
            thsIM.writeLog({
                content: context,
                prefix: 'Receive : 解析后的message'
            });
            
            var reg = new RegExp('hxnbsp', 'g');
            context = context.replace(reg, '&nbsp;');
            
            
            
            context = "<p>" + context + "</p>";
            data = {
                time: new Date().getTime(),
                from: from,
                text: context,
                id: id,
                local: false,
                nonProcess: false,
                capture: tempCaptureFlag,
                isDelayS: isDelayS,
                isNeedAutoSign: isNeedAutoSign
            };
            if (nameSpace == "jabber:x:delay") {
                var over = $(root).attr('over');
                data.over = over;
				var stamp = isDelay.attr("stamp");
				var sdate = this.convertStampTodate(stamp);
				data.time = new Date(sdate.year,sdate.month,sdate.day,sdate.hour,sdate.minute,sdate.second).getTime();
				var userinfo = $(root).find("from_info");
				data.userinfo = userinfo;
				
                this._controller.cacheOfflineMsg(data);
                
                return;
            }
            
            this._controller.onGetMessage(from, data, isDelayS);
            return;
        }else if(type == "SNS_NOTIFY"){
			//
			
			var $content = $root.find("content");
			var content = $content.text();
			
			this._controller.onGetWebGltMsg(content);
			return;
		}
        else 
            if (type == "sysad") {
                this._controller.onGetAd($root);
            }
            else 
                if (type == "groupchat") {
                    var nameSpace = $root.find('x').attr('xmlns');
                    if (NS && NS == NameSpace.file) {
                        var $file = $root.find('file');
                        var $stream = $root.find('streamhost');
                        data = {
                            version: $file.attr('old'),
                            action: $file.attr('action'),
                            fileId: $file.attr('id'),
                            digest: $file.attr('digest'),
                            name: $file.attr('name'),
                            size: $file.attr('size'),
                            token: $file.attr('token'),
                            host: $stream.attr('host'),
                            port: $stream.attr('port'),
                            from: $root.attr('from'),
                            type: $file.attr('type')
                        }
                        
						
						
                        if ($file.attr('type') == "img") {
                            var self = this;
                            setTimeout(function(){
                                self._controller.onsendCapture(data);
                            }, 500)
                        }
                        else {
                            this._controller.onSendFile(data);
                        }
                        
                        return;
                    }
                    
                    
                    
                    
                    var selfImid = this._imid;
                    if (selfImid && selfImid.indexOf('=') > -1) {
                        selfImid = selfImid.split('=')[1];
                    }
                    
                    from = from.substring(0, from.indexOf('@'));
                    var fromImid = $root.attr('fromjid');
                    fromImid = fromImid.substring(0, fromImid.indexOf('@'));
                    
                    if ($(root).find('html').get(0)) {
                        this._saveAnotherRecords1(from, fromImid, selfImid, $(root).find('html').get(0).xml);
                    }
                    else {
                        var tempBody = $(root).find('body').text();
                        tempBody = "<span><text>" + tempBody + "</text></span>"
                        this._saveAnotherRecords1(from, fromImid, selfImid, $(root).find('html').get(0).xml);
                    }
                    
                    Config.tempStr = '';
                    var context = XmlFileOperator.parseTool($root.find('span'), $root);
                    
                    var reg = new RegExp('hxnbsp', 'g');
                    context = context.replace(reg, '&nbsp;');
                    
                    
                    
                    context = "<p>" + context + "</p>";
                    data = {
                        fromImid: fromImid,
                        time: new Date().getTime(),
                        from: from,
                        text: context,
                        id: id,
                        local: false,
                        nonProcess: false,
                        capture: tempCaptureFlag,
                        isDelayS: isDelayS,
                        fromImid: fromImid
                    };
                    
                    
                    if (nameSpace == "jabber:x:delay") {
						var over = $(root).attr('over');
						data.over = over;
                        this._controller.cacheOfflineGroupMsg(data);
                        return;
                    }
                    else {
                        this._controller.onGetGroupMessage(data)
                    }
                    
                    
                    return;
                }
        
        if (!NS) {
            return;
        }
        switch (NS) {
        
            case NameSpace.file:
			
				
				
                var $file = $root.find('file');
                var $stream = $root.find('streamhost');
                data = {
                    version: $file.attr('old'),
                    action: $file.attr('action'),
                    fileId: $file.attr('id'),
                    digest: $file.attr('digest'),
                    name: $file.attr('name'),
                    size: $file.attr('size'),
                    token: $file.attr('token'),
                    host: $stream.attr('host'),
                    port: $stream.attr('port'),
                    from: $root.attr('from'),
                    type: $file.attr('type')
                }
              
                if ($file.attr('type') == "img") {
                    var self = this;
					var nameSpace = $root.find('x').attr('xmlns');
					if (nameSpace == "jabber:x:delay") {
						var over = $(root).attr('over');
						if(over == 1){
							this._controller.cacheOfflineFileMsg()
						}
					}
					
                    setTimeout(function(){
                        self._controller.onsendCapture(data);
                    }, 500)
                }
                else {
                    this._controller.onSendFile(data);
                }
                break;
            case NameSpace.assist:
                var $assist = $root.find('assist');
                var $stream = $root.find('streamhost');
                var action = $assist.attr('action');
                if (!action) {
                    return;
                }
                data = {
                    action: $assist.attr('action'),
                    host: $stream.attr('host'),
                    c_port: $stream.attr('c_port'),
                    s_port: $stream.attr('s_port'),
                    from: $root.attr('from'),
                    token: $assist.attr('token'),
                    id: $assist.attr('id') || ''
                }
                var from = data.from;
                if (from && from.indexOf("@") > -1) {
                    from = from.split('@')[0];
                }
                
                var param = {
                    'type': 'refuse_assist',
                    'toimid': from,
                    'id': data.id,
                    "token": data.token,
                    'action': "refuse"
                };
                this.sendConAssistRequest(param);
                
                var data = {
                    html: "&lt;text>对方版本还不支持远程协助&lt;/text>",
                    body: "",
                    toimid: from,
                    style: "FONT-FAMILY: 宋体; COLOR: #000; FONT-SIZE: 12pt"
                
                }
                this.sendMsg(data);
                return;                this._controller.onsendAssist(data);
                break;
            case GroupNameSpace.apply:
                
                
                var apply = $root.find('apply');
                var responce = $root.find('response');
                var groupid = $root.attr('from');
                if (groupid && groupid.indexOf('@') > -1) {
                    groupid = groupid.split('@')[0];
                }
                from = from.substring(0, from.indexOf('@'));
                if (apply && apply.attr('user_jid')) {
                    var data = {
                        groupid: groupid,
                        imid: apply.attr('user_jid'),
                        account: apply.attr('account'),
                        nick: apply.attr('nick'),
                        msg: apply.attr('msg'),
                        from: from
                    }
                    this._controller.onApplyJoin(data);
                }
                else 
                    if (responce && responce.attr('user_jid')) {
                        var data = {
                            groupid: groupid,
                            imid: responce.attr('user_jid'),
                            groupname: responce.attr('group_name'),
                            msg: responce.attr('msg'),
                            from: from,
                            action: responce.attr('action')
                        }
                        this._controller.onApplyAJoin(data);
                    }
                
                
                
                
                
                break;
            case GroupNameSpace.inivate:
                var invite = $root.find('invite');
                var groupid = $root.attr('from');
                if (groupid && groupid.indexOf('@') > -1) {
                    groupid = groupid.split('@')[0];
                }
                from = from.substring(0, from.indexOf('@'));
                
                
                this._controller.onInviteNotice({
                    groupid: groupid,
                    imid: invite.attr('inviter_jid'),
                    account: invite.attr('inviter_account'),
                    nick: invite.attr('inviter_nick'),
                    groupname: invite.attr('group_name'),
                    from: from,
                    action: "invite"
                });
                
                break;
            case GroupNameSpace.kicked:
                var group = $root.find('group');
                var groupid = $root.attr('from');
                if (groupid && groupid.indexOf('@') > -1) {
                    groupid = groupid.split('@')[0];
                }
                
                this._controller.onKickedNotice({
                    groupid: groupid,
                    groupname: group.attr('name')
                });
                
                //				<message type="group" from="111@group.hexin.glt" to="96735603@hexin.glt">
                //	<x xmlns='jabber:iq:muc#kicked'/>
                //		<group name="群组名"/>
                //	</x>
                //</message>
                
                break;
                
                
        }
    },
    //服务器返回的precence协议通知，主要负责状态通知
    presenceHandle: function(xmlDoc){
    
        var $root = $(xmlDoc.documentElement);
        var nickName = $root.attr("nick");
        var reject = $root.find('status').text();
        var $isAway = $root.find("show").text();
        var from = $root.attr('from');
        if (from.indexOf("@") > -1) {
            from = from.substring(0, from.indexOf("@"));
        }
        var data = {};
        
        if ($root.attr('type') === 'error') {
            return;
        }
        
        if ($root.attr('type') === 'subscribed') {
            var selfImid = $root.attr('to');
            var friendImid = $root.attr('from');
            if (selfImid.indexOf('@') > -1) {
                selfImid = selfImid.substring(0, selfImid.indexOf('@'));
            }
            if (friendImid.indexOf('@') > -1) {
                friendImid = friendImid.substring(0, friendImid.indexOf('@'));
            }
            data = {
                //                'selfImid': selfImid,
                'imid': friendImid,
                'name': $root.attr('nick')
            };
            this._controller.onAddFriends(data);
            return;
        }
        if ($root.attr('type') === 'subscribe') {
            this._controller.onReceiveAddFriendNotice($root)
        }
        else 
            if ($root.attr('type') === 'unsubscribed' && reject && reject == 'Reject') {
                var name = '';
                if (nickName) {
                    name = nickName;
                }
                else {
                    name = from;
                }
                
                this._controller.onReFuseAddFriendNotice(name);
                return;
                
            }
        
        
        
        if (!$root.attr('from')) 
            return;
        var from = $root.attr('from');
        if (from.indexOf("@") > -1) {
            from = from.substring(0, from.indexOf("@"));
        }
        if (Config.userGroupMap.get(from) == "blacklist") {
            return;
        }
        
        var tempStatus = '';
        if (nickName) {
            this._controller.changeUserName({
                'imid': from,
                'nickName': nickName
            });
            
        }
        if ($root.attr('type') === 'unavailable') {
            data[from] = {
                imid: from,
                status: "offline"
            };
            thsCache.callFunction({
                'name': "statusCall" + from,
                'param': {
                    'status': "offline"
                }
            })
            
            var groupid = $root.attr('group_jid');
            
            if (groupid) {
                groupid = groupid.substring(0, groupid.indexOf("@"));
                thsCache.callFunction({
                    'name': "noticeEvery_" + groupid,
                    'param': {
                        'type': 'changeStatus',
                        'status': "offline",
                        'userid': from
                    }
                });
            }
            
            
            
            this._controller.onGetUserStatus(data);
            return;
        }
        if ($isAway == "away") {
        
        
            data[from] = {
                imid: from,
                status: "offline"
            };
            thsCache.callFunction({
                'name': "statusCall" + from,
                'param': {
                    'status': "offline"
                }
            })
            
            var groupid = $root.attr('group_jid');
            if (groupid) {
                groupid = groupid.substring(0, groupid.indexOf("@"));
                thsCache.callFunction({
                    'name': "noticeEvery_" + groupid,
                    'param': {
                        'type': 'changeStatus',
                        'status': "offline",
                        'userid': from
                    }
                });
            }
            
            
            this._controller.onGetUserStatus(data);
            return;
        }
        else 
            if ($isAway == "chat") {
                data[from] = {
                    imid: from,
                    status: "online"
                };
                thsCache.callFunction({
                    'name': "statusCall" + from,
                    'param': {
                        'status': "online"
                    }
                })
                var groupid = $root.attr('group_jid');
                
                
                if (groupid) {
                    groupid = groupid.substring(0, groupid.indexOf("@"));
                    thsCache.callFunction({
                        'name': "noticeEvery_" + groupid,
                        'param': {
                            'type': 'changeStatus',
                            'status': "online",
                            'userid': from
                        }
                    });
                }
                
                
                this._controller.onNotifyAllClientStatus(data);
                return;
            }
        data[from] = {
            imid: from,
            status: "online"
        };
        
        thsCache.callFunction({
            'name': "statusCall" + from,
            'param': {
                'status': "online"
            }
        })
        
        var groupid = $root.attr('group_jid');
        
        if (groupid) {
            groupid = groupid.substring(0, groupid.indexOf("@"));
            thsCache.callFunction({
                'name': "noticeEvery_" + groupid,
                'param': {
                    'type': 'changeStatus',
                    'status': "online",
                    'userid': from
                }
            });
        }
        
        this._controller.onGetUserStatus(data);
        
    },
    
    //初始化登录，登录完成后，客户端接口通知我们已经登录成功
    initLogin: function(xmlText){
		
//		if($('.main_hd').css('display') == 'none') $('.main_hd').show();
		
        Config.whichState = "online";
        
        if (xmlText) {
            if (xmlText.indexOf(',') > -1) {
                var userId = xmlText.split(',')[1].split('=')[1];
                var userPath = xmlText.split(',')[2].split('=')[1];
                
                thsCache.setValue('thsAccountPath', userPath);
                thsCache.setValue('selfuserid', userId);
            }
            
            
            if (xmlText.indexOf('@') > -1) {
                var tmp = xmlText;
                tmp = tmp.substring(0, tmp.indexOf('@'));
                if (tmp.indexOf('=') > -1) {
                    tmp = tmp.split('=')[1];
                }
                
                this.setSelfImid(tmp);
                var domain = xmlText;
                domain = domain.substring(domain.indexOf('@') + 1, domain.length);
                this.setDomain(domain);
            }
        }
        this.setChatWindowMin(null, 280, 610);
        try {
			$("#offlineContent").hide();
			$("#proceContent").hide();
			$("#loginFail").hide();
		    $('.userStatus').css('background-position', '-30px -1231px');
		    Config.isOfflineStatus = false;
		    $('#offlineContent').hide();
		    $('.headImg').removeClass('grayHead');
		    $('#proceContent').hide();
		    Config.curShowDiv.show();
		} catch (e) {
		}
        
    },
    
    //联系客服（之前嵌行情的联系客服通知）
    onNotifyBrokerOpenChat: function(imid){
        this._controller.onNotifyBrokerOpenChat(imid);
    },
    
    //激活窗口通知。
    onNotifyActiveChat: function(imid){
        //		thsIM.writeLog({
        //            content: "激活窗口 ：",
        //            prefix: 'Active : 激活窗口'
        //        });
        
        var data = {
            imid: imid,
            type: "active"
        }
        this._controller.onActiveNotice(data);
        //this.sendStaticsActiveTimes("active");
        this._controller.onNotifyChatActive(imid);
        
    },
    
    //非激活通知
    onNotifyUnActiveChat: function(imid){
        var data = {
            imid: imid,
            type: "inactive"
        }
        
        this._controller.onActiveNotice(data);
        
        
        //		this.sendStaticsActiveTimes("inactive");
    },
    
    
    //发送激活协议
    sendStaticsActiveTimes: function(param){
        var msg = [];
        msg.push('<iq type="set">', '<x xmlns="jabber:iq:winop" action="', param.type, '" figure="', param.figure, '"/>', '</iq>');
        var request = new IMRequest(msg.join(''));
        this.sendRequest(request);
    },
    
    //股灵通异常处理 
    errorTipMethod: function(operCode){
		
		if(parseInt(operCode) == 102){
				
				$('.userStatus').css('background-position', '-70px -1231px');
		        Config.curShowDiv.hide();
				$('#loginFail').hide();
		        $('.headImg').addClass('grayHead');
		        Config.isOfflineStatus = true;
		        $('#offlineContent').show();
				
				 //重新登录
		        new FormElement($('#relogin'), function(){
		            $('.userStatus').css('background-position', '-30px -1231px');
		            Config.isOfflineStatus = false;
		            $('#offlineContent').hide();
		            $('.headImg').removeClass('grayHead');
		            $('#proceContent').hide();
		            Config.curShowDiv.show();
		            $('#friends').html('<img class="loginLoading" src="./images/index/mainloading.gif" />');
		            thsIM.login();
		        }).init();
		        
				return;
		}
		
		
        var tipText = '';
        var codeNum = parseInt(operCode);
        
        switch (codeNum) {
            case 204:
                tipText = '用户名密码错误，您的股灵通不能成功<br />的登录';
                break;
            case 210:
                tipText = '认证失败，您的股灵通不能成功的登录';
                break;
            case 101:
                tipText = '接收数据失败';
                break;
            case 102:
//                tipText = '连接失败, 可能<br />(1)计算机没有连接到互联网<br />(2)上网代理设置不正确<br />(3)防火墙不允许访问网络';
			
			
                break;
            case 103:
                tipText = '发送数据失败';
                break;
            case 104:
                tipText = 'base64失败';
                break;
            default:
                return;        
		}
		
		$('.main_hd').hide();   //隐藏二级子菜单
		$('#proceContent').hide();
		$('#offlineContent').hide();
		$('#loginFail').find('span').html(tipText);
		$('#loginFail').find('span').css('margin-top','-30px').css('margin-left','-20px');
        $('#loginFail').show();
		Config.curShowDiv.hide();
		
					
		
		Config.isException = true;
    },
    //被迫下线
    proceDown: function(){
        $('#offlineContent').hide();
        Config.curShowDiv.hide();
        $('.headImg').addClass('grayHead');
        Config.isProceStatus = true;
        $('.userStatus').css('background-position', '-70px -1231px');
        $('#proceContent').show();
    },
    
    loginHandle: function(){
        //		this._controller.
    },
    
    getUserInfo: function(){
    
        var xml = [];
        xml.push('<iq id="1" type="get">', '<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0"/>', '</iq>');
        xml = xml.join('');
        var request = new IMRequest(xml);
        this.sendRequest(request);
    },
    
    //发送获取好友列表协议
    getRoster: function(){
        var xml = [];
        xml.push('<iq id="3" type="get">', '<query xmlns="jabber:iq:roster"/>', '</iq>');
        xml = xml.join('');
        var request = new IMRequest(xml);
        this.sendRequest(request);
    },
    
    //发送获取好友状态协议
    getPresence: function(){
        var xml = [];
        xml.push('<presence type="available">', '<show>chat</show>', '</presence>');
        xml = xml.join('');
        var request = new IMRequest(xml);
        this.sendRequest(request);
    }    /**
     * Author quanlucan （quanlucan@myhexin.com）
     * SEND XML 2011-12-27
     * 删除好友
     */
    ,
    deleteUser: function(imid, groupName){
        var toImid = imid + "@hexin.glt";
        var xmlStr = "<presence type='unsubscribe' to='" + toImid + "'/>";
        var request = new IMRequest(xmlStr);
        this.sendRequest(request);
        this.trueDeleteUser({
            'imid': imid,
            'groupName': groupName
        });
    }    /**
     * Author quanlucan （quanlucan@myhexin.com）
     * SEND XML 2011-12-27
     * to setrelation and truely delete user
     */
    ,
    trueDeleteUser: function(data){
        if (data && data.imid) {
            var jid = data.imid + "@hexin.glt";
            var groupName = data.groupName;
            var xml = [];
            xml.push('<iq id="23" type="set">', '<query xmlns="jabber:iq:roster">', '<item subscription="remove" jid="', jid, '">', '<group>', groupName, '</group>', '</item>', '</query>', '</iq>');
            var request = new IMRequest(xml.join(''));
            this.sendRequest(request);
        }
    }    /**
    
     * Author quanlucan （quanlucan@myhexin.com）
    
     * SEND XML 2011-12-27
    
     * to setrelation and truely delete user
    
     */
    
    ,
    
    //移动好友列表（暂时没用到）
    moveUser: function(imid, gname){
        if (imid && gname) {
            var toImid = imid + "@hexin.glt";
            var xmlStr = "<presence type='unsubscribe' to='" + toImid + "'/>";
            var request = new IMRequest(xmlStr);
            this.sendRequest(request);
            this.setMovedUser(imid, gname);
        }
    },
    
    setMovedUser: function(imid, gname){
        if (imid && gname) {
            var toImid = imid + "@hexin.glt";
            var xml = [];
            xml.push('<iq id="8" type="set">', '<query xmlns="jabber:iq:roster">', '<item jid="', toImid, '">', '<group>', gname, '</group>', '</item>', '</query>', '</iq>');
            var request = new IMRequest(xml.join(''));
            this.sendRequest(request);
            
        }
    }    /**
     * 连接断开时响应
     */
    ,
    onDisconnect: function(data){
        this.disableRequest();
        this._controller.onDisconnect(data);
    }    /**
     * 本地通知所有窗口的操作
     *
     * @param {Object} obj  所需传递给其他窗口的的数据
     */
    ,
    onNotifyAllClient: function(obj){
        this._controller.onNotifyAllClient(obj);
    }    /**
     * 发送请求操作
     *
     * @param   {Object}    request 请求数据包
     * @param   {Object}    obj     请求包
     * @return  {boolean}
     */
    ,
    sendRequest: function(request, obj){
        if (Ext.isObject(obj)) {
            obj.requestTime = (new Date()).getTime();
            request.id = obj.id = this._idPrefix + (++this._packageId);
            this._packages.push(obj);
        }
        
        return this._client.sendRequest(request);
    }    // 发送消息
    // @param   content 发送的文本内容
    // @param   faces   自定义表情
    // @param   toimid  接收者的imid
	
	,getKaichangbai : function(data){
		var self = this;
		var htmlArr =[];
		htmlArr.push(
			'<message type="chat" sid="',this._imid,'" to="',data.to,'@hexin.glt"  mtype="getsalerinfo"></message>'
		);
		msg = htmlArr.join('');
		
        var request = new IMRequest(msg);
        this.sendRequest(request);
	}
	
    ,
    sendMsg: function(data, obj){
        var msg = [];
        var flag = false;
        var id = new Date().getTime();
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        if (data && data.type && data.type == 'capture') {
            var test = data.html;
			if(Config.isFriend[data.toimid]){
				msg.push('<message type="chat" to="', data.toimid, '@hexin.glt" id="', id, '" from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;text> &lt;/text>&lt;/span>&lt;/body></html>', '</message>');
            	flag = true;
			}else{
				msg.push('<message type="chat" chat_type="nofriend" to="', data.toimid, '@hexin.glt" id="', id, '" from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;text> &lt;/text>&lt;/span>&lt;/body></html>', '</message>');
				flag = true;
				
			}
            
        }
        else {
			if (Config.isFriend[data.toimid]) {
				var test = data.html;
            	msg.push('<message type="chat" to="', data.toimid, '@hexin.glt" id="', id, '" from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;/span>&lt;/body></html>', '</message>');
			}else{
				var test = data.html;
				if(data.firstmsg == "yes"){
					msg.push('<message type="chat" isfirst="1" chat_type="nofriend" to="', data.toimid, '@hexin.glt" id="', id, '" from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;/span>&lt;/body></html>', '</message>');
				}else{
					msg.push('<message type="chat" chat_type="nofriend" to="', data.toimid, '@hexin.glt" id="', id, '" from="', selfImid, '@hexin.glt">', '<body>' + data.body + '</body>', '<html>&lt;body>&lt;span style=&quot;', data.style, '&quot;>', test, '&lt;/span>&lt;/body></html>', '</message>'); 
				}
			}
			
        }
        msg = msg.join('');
        var request = new IMRequest(msg);
        
        this.sendRequest(request);
        //quanlucan
        
        if (flag) {
        	
            this.sendFile(data);
        }
    },
	//get gltcode by userid
	getGltNumByUserId : function(userid){
		//<iq type="get" op="userid"><query xmlns="jabber:iq:getotherinfo"/><user userid="2323232"  ></iq>

		var msg = [];
		msg.push(
			'<iq type="get" op="userid"><query xmlns="jabber:iq:getotherinfo"/><user userid="',userid,'" /></iq>'
		)
		msg = msg.join('');
        var request = new IMRequest(msg);
		this.sendRequest(request);
	},
	//get userid by gltcode
	getUseridbygltnum : function(imid){
		var msg = [];
		msg.push(
			'<iq type="get" op="gltcode"><query xmlns="jabber:iq:getotherinfo"/><user gltcode="',imid,'" /></iq>'
		)
		msg = msg.join('');
        var request = new IMRequest(msg);
		this.sendRequest(request);
	},
	
    /**
     *
     * @param {Object} param
     *
     * 发送文件
     */
    sendFile: function(data){
		
		
        var fileMsg = [];
        var self = this;
        if (data && data.type && data.type == 'capture') {
            $.each(data.captureObjs, function(){
                fileMsg = [];
                fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="', data.captureType, '"  id="', this.captureId, '" digest="', this.capDigest, '" name="', this.captureId, '" type="img" size="', this.captureSize, '"/>', '</message>');
                
                fileMsg = fileMsg.join('');
                var request = new IMRequest(fileMsg);
                self.sendRequest(request);
                
            });
            return;
            
        }
        else {
            fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="send"  id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="" size="', data.fileSize, '"/>', '</message>');
            
            
        }
        
        
        fileMsg = fileMsg.join('');
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    
    //发送文件夹
    sendfolder: function(data){
        var fileMsg = [];
        
        
        fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="send"  id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="folder" size="', data.fileSize, '"/>', '</message>');
        
        
        
        
        fileMsg = fileMsg.join('');
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    //发送离线文件
    sendoffLineFile: function(data){
        var fileMsg = [];
        if (data && data.type && data.type == 'capture') {
            fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="offlinefile"  id="', data.captureId, '" digest="', data.fileDigest, '" name="', data.captureId, '" type="img" size="', data.fileSize, '"/>', '</message>');
        }
        else {
            fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="offlinefile"  id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="" size="', data.fileSize, '"/>', '</message>');
        }
        
        fileMsg = fileMsg.join('');
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    //发送接收文件
    acceptFile: function(data){
        var fileMsg = [];
        var type = data.imgtype;
        if (!type) {
            type = '';
        }
        if (data.toimid.indexOf('@') > -1) {
            fileMsg.push('<message type="file" to="', data.toimid, '">', '<file xmlns="jabber:iq:file" action="agree" id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="', type, '" token="', data.token, '" size="', data.fileSize, '">', '<streamhost jid="" host="', data.host, '" port="', data.port, '"/></file>', '</message>');
        }
        else {
            fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="agree" id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="', type, '" token="', data.token, '" size="', data.fileSize, '">', '<streamhost jid="" host="', data.host, '" port="', data.port, '"/></file>', '</message>');
        }
        fileMsg = fileMsg.join('');
		
		
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    
    
    
    //发送远程协助
    sendAssist: function(param){
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var reqArr = [];
        
        //	   <message type="assist" id="WtzJz-30" 
        //to="test1@127.0.0.1/hexin.glt" from="test2@127.0.0.1/hexin.glt">
        //    <assist xmlns="jabber:iq:assist" action="request"/>
        //</message>
        var randomNum = Math.floor(Math.random() * 100000 + 1);
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="request" id="', randomNum, '"/>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //取消远程协助
    sendCancelAssist: function(param){
        //		this.sendConAssistRequest(param);
        //		
        //		return;
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var reqArr = [];
        
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="cancel"/>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //接收远程协助
    sendConAssistRequest: function(param){
    
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var token = param.token;
        var id = param.id;
        var host = param.host;
        var reqArr = [];
        
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="', param.action, '" token= "', token, '" id="', id, '">', '</assist>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //断开远程协助
    sendDisConcontrol: function(param){
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var token = param.token;
        var id = param.id;
        var host = param.host;
        var reqArr = [];
        
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="confirm" token= "', token, '" id="', id, '">', '</assist>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //停止远程控制协议
    sendStopcontrol: function(param){
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var token = param.token;
        var id = param.id;
        var host = param.host;
        var reqArr = [];
        
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="confirm" token= "', token, '" id="', id, '">', '</assist>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //发送远程协助请求
    sendReqcontrol: function(param){
        this.sendConAssistRequest(param);
    },
    
    //发送正在输入协议
    sendInputTing: function(param){
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toImid;
        var reqArr = [];
        reqArr.push('<iq type="get" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<query xmlns="jabber:iq:inputting" action="', param.action, '">', '</query>', '</iq>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    //发送确认协助请求
    sendConfirmAssist: function(param){
        var selfImid = this._imid;
        if (selfImid && selfImid.indexOf('=') > -1) {
            selfImid = selfImid.split('=')[1];
        }
        var toImid = param.toimid;
        var token = param.token;
        var id = param.id;
        var host = param.host;
        var reqArr = [];
        
        reqArr.push('<message type="assist" to="', toImid, '@hexin.glt" from="', selfImid, '@hexin.glt">', '<assist xmlns="jabber:iq:assist" action="confirm" token= "', token, '" id="', id, '">', '</assist>', '</message>');
        var request = new IMRequest(reqArr.join(''));
        this.sendRequest(request);
    },
    
    
    //<presence type="subscribed" to="129891802@hexin.glt" from="129059448@hexin.glt" nick="蓝色生死恋">同意</presence>
    //接受好友请求  selfImid friendImid nickName
    sendAgreePres: function(data){
        var addFriendMsg = [];
        addFriendMsg.push('<presence type="subscribed" to="', data.friendImid, '@hexin.glt" from="', data.selfImid, '@hexin.glt" nick="', data.nickName, '" >同意</presence> ');
        var request = new IMRequest(addFriendMsg.join(''));
        this.sendRequest(request);
    },
    
    //拒绝添加好友
    sendRefusePres: function(imid){
        var refuseFriendMsg = [];
        refuseFriendMsg.push('<presence type="unsubscribed" to="', imid, '@hexin.glt">	', '<status>Reject</status>', '</presence>');
        var request = new IMRequest(refuseFriendMsg.join(''));
        this.sendRequest(request);
    },
    
    //拒绝接受文件
    refuseFile: function(data){
        var fileMsg = [];
        var type = data.imgtype;
        if (!type) {
            type = '';
        }
        fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="refuse" id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="', type, '" token="', data.token, '" size="', data.fileSize, '">', '<streamhost jid="" host="', data.host, '" port="', data.port, '"/></file>', '</message>');
        
        var request = new IMRequest(fileMsg.join(''));
        this.sendRequest(request);
    },
    
    //取消发送
    cancelFile: function(data){
        var fileMsg = [];
        var type = data.imgtype;
        if (!type) {
            type = '';
        }
        fileMsg.push('<message type="file" to="', data.toimid, '@hexin.glt">', '<file xmlns="jabber:iq:file" action="cancel" id="', data.fileId, '" digest="', data.fileDigest, '" name="', data.fileName, '" type="', type, '" token="', data.token, '" size="', data.fileSize, '">', '<streamhost jid="" host="', data.host, '" port="', data.port, '"/></file>', '</message>');
        fileMsg = fileMsg.join('');
        var request = new IMRequest(fileMsg);
        this.sendRequest(request);
    },
    
    /**
     *
     * @param {Object} param
     *
     * 添加好友时，发送验证信息
     */
    sendAddFriendPres: function(data){
        var addFriendMsg = [];
        addFriendMsg.push('<presence type="subscribe" to="' + data.toImid + '@hexin.glt">', data.text, '</presence>');
        addFriendMsg = addFriendMsg.join('');
        var request = new IMRequest(addFriendMsg);
        this.sendRequest(request);
    },
    
    sendAddFriendIq: function(data){
        var addFriendMsg = [];
        addFriendMsg.push('<iq id="35" type="set">', '<query xmlns="jabber:iq:roster"> ', '<item jid="', data.toImid, '@hexin.glt"', '/>', '</query>', '</iq>');
        addFriendMsg = addFriendMsg.join('');
        var request = new IMRequest(addFriendMsg);
        this.sendRequest(request);
        this.sendAddFriendPres(data);
    },
    
    //直接发添加好友协议，没有验证信息
    sendAddFriendImiat: function(imid){
        var addFriendMsg = [];
        addFriendMsg.push('<iq id="35" type="set">', '<query xmlns="jabber:iq:roster"> ', '<item jid="', imid, '@hexin.glt"', '/>', '</query>', '</iq>');
        addFriendMsg = addFriendMsg.join('');
        var request = new IMRequest(addFriendMsg);
        this.sendRequest(request);
        this.sendAddFriendImiaPres(imid);
    },
    
    sendAddFriendImiaPres: function(imid){
        var addFriendMsg = [];
        addFriendMsg.push('<presence type="subscribe" to="' + imid + '@hexin.glt" />');
        addFriendMsg = addFriendMsg.join('');
        var request = new IMRequest(addFriendMsg);
        this.sendRequest(request);
    },
    //获取好友信息协议
    sendGetVCard: function(imid){
        var xml = [];
        xml.push('<iq id="10" type="get" to="', imid, '@hexin.glt">', '<vCard xmlns="vcard-temp" prodid="-//HandGen//NONSGML vGen v1.0//EN" version="2.0">', '<X-NEW>1</X-NEW>', '</vCard>', '</iq>')
        xml = xml.join('');
        var request = new IMRequest(xml);
        this.sendRequest(request);
    },
    
    //章晓健 SNS改变状态
    sendUserStatus: function(status){
        var xml = [];
        if (status == 'offline') {
            xml.push('<presence type="unavailable"/>')
        }
        else {
            xml.push('<presence type="available">', '<show>', status, '</show>', '</presence>');
        }
        xml = xml.join('');
        var request = new IMRequest(xml);
        this.sendRequest(request);
    },
    
    
    
    
    enableRequest: function(){
        this._client.disableRequest(false);
    },
    disableRequest: function(){
        this._client.disableRequest(true);
    },
    notifyAllClient: function(obj){
        if (Ext.isEmpty(obj)) {
            obj = {};
        }
        this._client.notifyAllClient(obj);
    }    // 打开一个聊天窗口
    // @param imid      聊天对象的imid
    // @param param     额外所需传入的参数
    // @param cx        窗口的宽度，仅对新窗口有效
    // @param cy        窗口的高度，仅对新窗口有效
    // @param showType  对话框显示类型，暂时只有“normal”类型用于重新激活打开
    ,
    openChatWindow: function(imid, param, cx, cy, showType, _title){
        thsIM.openChatWindow({
            imid: imid,
            url: param,
            width: cx || 595,
            height: cy || 430,
            
            show: showType || '',
            title: _title || ''
        });
        //        return this._client.openChatWindow(imid, param, , cy || 380, showType, _title);
    },
    
    //根据股灵通号判断窗口是否打开
    isChatOpen: function(imid){
        return this._client.isChatOpen(imid);
    },
    
    
    // 限定对话框的最小拉伸范围
    setChatWindowMin: function(toimid, width, height){
        this._client.setChatWindowPos({
            imid: toimid,
            opt: 'minsize',
            cx: width || '550',
            cy: height || '380'
        });
    }    // 设置对话框的显示位置及其大小...
    ,
    setChatWindowPos: function(obj){
        this._client.setChatWindowPos(obj);
    },
    
    //调用客户端截屏控件
    screenCapture: function(opt){
        return this._client.screenCapture(opt);
    }
    
});

(function(){
    // 全局的im对象，避免引起内存泄漏
    if (!Config.isWebClient) {
        __IM__ = external.createObject('InstantMessager');
    }
})();

// 客户端嵌入的请求对象
IMClient = Class.extend({

    // 初始化
    // @param   controller  控制器对象，从IMController派生
    init: function(controller){
        var ops = ["none", // none               无
 "logon", // logon              登入
 "logout", // logout             登出
 "gl", // get userlist       取得好友列表
 "gs", // get friend status  取得好友在线状态
 "ss", // set status         设置自己在线状态
 "sm", // send message       发送信息
 "gm", // get message        获得信息
 "sf", // send file          发送附件
 "gf", // get file           获得附件
 "ou", // oper user          操作好友列表
 "qu", // query user         查询用户
 "ko", // kick off           踢掉离线
 "sa", // server add         增加服务器
 "sd", // server delete      删除服务器
 "lr", // log record         记录日志
 "init", // initlize           初始化
 "disconnect", // disconnect         连接断开
 "ui", // user info          用户信息
 "offline", // offline            离线信息
 "gu", // get userinfo       获取用户资料
 "su", // set userinfo       设置用户资料
 "qc", // query comment      请求评述
 "sc", // set comment        设置评述
 "gc", // get comment        返回评述
 "gi", // get serviceimid    获取imid(客服分配)
 "fs", // forward service    转接服务
 "gw", // get forward        获取转接信息
 "se", // server enable
 "go", // get offlineinfo    获取离线信息
 "gfi", // get firendinfo     获取好友基本信息
 "sv", // server valid       服务器有效
 "sii", // server invalid     服务器无效
 "sr", // service request    客户请求客服（发送客服）
 "as", // accept service     客服应答请求
 "gsl", // get service list   获取客服列表
 "af", // accept forward     接受转接
 "df", // deny forward       拒绝转接
 38, 39, 40, 41, 42, 43, 44, 45, 46, 47, 48, 49, 'fu', // upload over
 'fd', // file download
 'fc', // file cancel
 'hs', // header image
 'sml', // published
 'gmgr', //create new group
 'cug', //move to other group
 'glsu', //fetch latest serviceid
 'slsu', //set latest serviceid
 'ga', //获取客服信息列表
 'sus' //搜索客户列表
];
        
        this._opmap = {};
        for (var i = 0; i < ops.length; ++i) {
            if (ops[i] == 'gmgr') {
                this._opmap[ops[i]] = 65;
            }
            else 
                if (ops[i] == 'cug') {
                    this._opmap[ops[i]] = 64;
                }
                else 
                    if (ops[i] == 'glsu') {
                        this._opmap[ops[i]] = 69;
                    }
                    else 
                        if (ops[i] == 'slsu') {
                            this._opmap[ops[i]] = 70;
                        }
                        else 
                            if (ops[i] == 'ga') {
                                this._opmap[ops[i]] = 71;
                            }
                            else 
                                if (ops[i] == 'sus') {
                                    this._opmap[ops[i]] = 73;
                                }
                                else {
                                    this._opmap[ops[i]] = i;
                                }
        }
        
        this._imHandler = new IMHandler(this, controller);
        this._disableRequest = false;
        __IM__.registerEvent(this.callback(this));
        
    },
    destroy: function(){
        this._opmap = null;
        this._imHandler = null;
    },
    disableRequest: function(disable){
        this._disableRequest = disable;
    } // 取得_imHandler对象
    ,
    getIMHandler: function(){
        return this._imHandler;
    } // 根据opname获得opcode
    // @param   opname  表示op的字符串
    ,
    getOperCode: function(opname){
        if (typeof this._opmap[opname] == 'undefined') {
            return 0;
        }
        else {
            return this._opmap[opname];
        }
    } // 发送请求包
    // @param:  Object params. 发送请求包的内容。必须包含'op'
    ,
    sendRequest: function(request){
        //        if (request.op != 'logon' && this._disableRequest) {
        //            return;
        //        }
        return __IM__.sendRequest(request);
    } // 打开聊天窗口
    ,
    isChatOpen: function(imid){
        return __IM__.isChatOpen({
            'imid': imid
        });
    } // 打开聊天窗口
    ,
    openChatWindow: function(imid, param, cx, cy, showType, _title){
        return __IM__.openChatWindow({
            imid: imid,
            width: cx,
            height: cy,
            param: param || '',
            show: showType || '',
            title: _title || ''
        });
    },
    notifyAllClient: function(obj){
        return __IM__.notifyAllClient(obj);
    },
    setChatWindowPos: function(obj){
        return __IM__.setChatWindowPos(obj ||
        {
            opt: 'fillview',
            rate: 100
        });
    },
    
    screenCapture: function(opt){
        return __IM__.screenCapture(opt);
    }    // 回调.
    // @param scope IMClient对象自身
    ,
    callback: function(scope){
        return function(operCode, xmlText){
			scope._imHandler.errorTipMethod(operCode);
        	switch(operCode) {
				case  0x0001 :
					scope._imHandler.theoryStockCallback(xmlText);
					break;
				case 0x000a :
					scope._imHandler.getTookenCallback(xmlText);
					break;
					
				case 0x0050:
					scope._imHandler.sysAndFensiMsgCallback(xmlText)
					break;
				case 0x0009:
					thsCache.setValue('headImageChange', 'yes');
					break;
				case 16:
					scope._imHandler.onNotifyBrokerOpenChat(xmlText);
					break;
				case 0x0013:
					scope._imHandler.onNotifyActiveChat(xmlText);
					break;
				case 0x0015:
					scope._imHandler.onNotifyUnActiveChat(xmlText);
					break;
				case 0x0040:
					thsCache.callFunction({
						'name' : 'whichCode',
						'param' : xmlText
					});
					break;
				case 0x0014 :
					scope._imHandler.onNotifyUnActiveChat(xmlText);
					break;
				case 505:
					scope._imHandler.proceDown();
					break;
				case 0x0011 :
					scope._imHandler.onDisconnect();
					break;
				case 0x0008:
					scope._imHandler.ifNeedJustFy(xmlText);
					break;
				case 0x0006 :
					 var isIn = thsCache.getValue('isLogin');
                    //							  thsIM.writeLog({
                    //                                    content: "从客户端接口获得认证成功通知",
                    //                                    prefix: 'Receive : 从客户端接口获得认证成功通知'
                    //                              });
                    if (isIn == 'yes' || !isIn) {
                        scope._imHandler.initLogin(xmlText);
                    }
					break;
				case 0x0007:
					scope._imHandler.loginHandle(xmlText);
					break;
				default :
				
				 	var xmlDoc = new ActiveXObject('MSXML2.DOMDocument.3.0');
                    xmlDoc.async = false;
                    //test
                    //								if(operCode == 0x0003){
                    //									var reg4 = new RegExp("<BR>","&lt;BR&gt;")
                    xmlText = xmlText.replace(/&/g, '&amp;');
                    xmlText = xmlText.replace(/<BR>/g, '&lt;BR&gt;');
                    //									xmlText = xmlText.replace(/</g,'&lt;');
                    var reg2 = new RegExp("&amp;lt;", "g")
                    xmlText = xmlText.replace(reg2, '&lt;');
                    var reg3 = new RegExp("&amp;amp;", "g")
                    xmlText = xmlText.replace(reg3, '&amp;');
                    //									&amp;amp;
                    if (!xmlDoc.loadXML(xmlText)) {
                        xmlText = xmlText.substring(0, xmlText.indexOf("<body>")) + xmlText.substring(xmlText.indexOf("</body>") + "</body>".length, xmlText.length);
                    }
                    //								}
                    if (xmlDoc.loadXML(xmlText)) {
                        if (operCode == 0x0002) {
                            scope._imHandler.iqHandle(xmlDoc);
                        }
                        else 
                            if (operCode == 0x0003) {
								
								
                                thsIM.writeLog({
                                    content: xmlText,
                                    prefix: 'Receive : 从客户端接口获得message(解析前)'
                                });
								
                                scope._imHandler.msgHandle(xmlDoc);
                                
                            }
                            else 
                                if (operCode == 0x0004) {
                                    scope._imHandler.presenceHandle(xmlDoc);
                                }
                        
                    }
                    xmlDoc = null;
					break;
			}
        };
    }
});

ScreenCaptureActiveX = null;
getScreenCaptureObj = function(){
    if (!Ext.isIE) {
        return false;
    }
    
    var installScreenCapture = function(){
        if (!$('#ScreenCapture').size()) {
            $('body').prepend(['<OBJECT id="ScreenCapture" classid="clsid:5865F055-6489-4650-BFD2-DD38C873BE77" ', 'codebase="./plugins/ScreenCaptureOcx.cab#version=1, 0, 0, 1" style="display:none;">', '</OBJECT>'].join(''));
        }
    };
    
    if (!ScreenCaptureActiveX) {
        try {
            ScreenCaptureActiveX = new ActiveXObject('SCREENCAPTUREOCX.ScreenCaptureOcxCtrl.1');
            installScreenCapture();
            if (!ScreenCaptureActiveX) {
                return false;
            }
        } 
        catch (e) {
            installScreenCapture();
            return false;
        }
    }
    return ScreenCapture;
};


// 封装一个请求
IMRequest = function(xmlText){
    if (!xmlText) {
        return;
    }
    
    // to check xml is right?
    var xmlDoc = new ActiveXObject('Microsoft.XMLDOM');
    var strDoc;
    xmlDoc.async = false;
    try {
    
    
        xmlDoc.loadXML(xmlText);
        
        if (typeof(xmlDoc) == "object") 
            strDoc = xmlDoc.xml;
        else 
            strDoc = xmlDoc;
    } 
    catch (e) {
        return;
    }
    
    
    var request = {
        // 'xml': strDoc
        'xml': xmlText
    };
    return request;
};

IMController = Class.extend({
    // 登录操作后的通知消息
    onLogon: function(data){
    },
    
    // 登出操作后的通知消息
    onLogout: function(data){
    },
    
    // 意外掉线后的通知消息
    onDisconnect: function(data){
    },
    
    
    // 消息推过来之后的通知消息
    onGetMessage: function(data){
    },
    
    // 取得好友列表后的通知消息
    onGetUserList: function(data){
    },
    
    // 取得好友信息后的通知消息
    onGetFriendInfo: function(data){
    },
    
    // 取得用户信息后的通知消息
    onGetUserInfo: function(data){
    },
    
    // 取得用户信息失败后的通知消息
    onGetUserInfoFail: function(data){
    },
    
    // 设置用户心情后的通知消息
    onSetUserMood: function(data){
    },
    
    // 取得用户状态后的通知消息
    onGetUserStatus: function(data){
    },
    
    // 设置用户状态后的通知消息
    onSetUserStatus: function(data){
    },
    
    // 获取客服列表后的通知消息
    onGetContactStaffUserList: function(data){
    },
    
    // 请求客户评分的通知消息
    onRequestUserComment: function(data){
    },
    
    // 取得客服打分后的通知消息
    onGetComment: function(data){
    },
    
    // 设置客服得分后的通知消息
    onSetComment: function(data){
    },
    
    // 本地窗口间的通知消息
    onNotifyAllClient: function(data){
    },
    
    onGetServiceRequest: function(data){
    },
    
    onGetContactStaffConfirm: function(data){
    },
    
    onGetForward: function(data){
    },
    
    onGetAcceptForward: function(data){
    },
    
    onGetDenyForward: function(data){
    },
    
    onGetUploadFileName: function(data){
    },
    
    onGetKickOffPackage: function(data){
    },
    
    setViewSelfImid: function(imid){
    },
    
    setViewToImid: function(toimid){
    },
    
    onClearData: function(imid){
    }
});

var destroyImEngine = function(){
    __IM__ = null;
    ImageCache = null;
    ScreenCaptureActivex = null;
    getScreenCaptureObj = null;
    IMRequest = null;
    IMHandler = null;
    IMClient = null;
    IMController = null;
};
