/**
 * 日志类
 * @author: 卢海宁<luhaining@myhexin.com>
 * @create: 2013-11-11
 */
var Log = Class.extend({
	
	enable: false,
	
	init: function(){ },
	
	open: function(){
		this.enable = true;
	},
	
	getTime: function(){
		var d = new Date();
		var s = d.toLocaleString();
		return s;
	},
	
	log: function(str){
		if(!this.enable){
			return;
		}
		alert(str);
	}
});

/**
 * 文件型日志输出类（需要客户端FileStreamOutput接口支持）
 * @author: 卢海宁<luhaining@myhexin.com>
 * @date: 2013-11-11
 */
var FileLog = Log.extend({
	implerror: false, // private
	path: null, // private
	fso: null, // private
	/* 
	 * @param cfg object 初始化的配置
	 *		cfg.filename 日志文件名 默认为日期格式的yyyy-MM-dd.log
	 *		cfg.dir 输出路径 默认为当前exe所在目录
	 */
	init: function(cfg){
		this._super();
		cfg = cfg || {};
		var filename;
		if(!cfg.filename){
			var date = new Date();
			var m = ((date.getMonth() + 1)/10).toFixed(1).replace('.', '');
			filename = [date.getFullYear(), m, date.getDate()].join('-') + '.log';
		}else{
			filename = cfg.filename;
		}
		var dir = cfg.dir || external.getModulePath();
		this.path = dir + 'logs/' + filename;
		try {
			this.fso = new FileStreamOutput();
			var success = this.fso.openSupple(this.path, true); // true追加 false覆盖
			if(!success){
				this.implerror = true;
				alert('日志接口初始化失败！FileLog.js');
			}
			this.fso.close();
		} catch(e) {
			this.implerror = true; // 接口初始化失败
		}
	},
	
	getLog: function(level, info){
		var line = '------------------\r\n' + level + " | " + this.getTime() + '\r\n------------------\r\n' + info + '\r\n';
		return line;
	},
	
	writeLog: function(log){
		var result = null;
		try {
			this.fso.openSupple(this.path, true);//true追加 false覆盖
			result = this.fso.write(log);
		} catch(e) {
			this.implerror = true; // 文件打开失败
			alert('日志接口异常！FileLog.js');
		} finally {
			try {
				this.fso.close();
			} catch(e) { }
		}
		return !!result;
	},
	/*
	 * @param Stringh
	 */
	log: function(info){
		if(!this.enable || this.implerror){
			return;
		}
		var log = this.getLog('日志', info);
		return this.writeLog(log);
	},
	
	error: function(info){
		if(!this.enable || this.implerror){
			return;
		}
		var log = this.getLog('错误', info);
		return this.writeLog(log);
	},
	
	destroy: function(str){
		this.fso.close();
		this.implerror = null;
		this.path = null;
		this.fso = null;
		delete this.implerror;
		delete this.path;
		delete this.fso;
	}
});

/**
 * Element型日志输出类，在文档流中显示日志
 * @author: 卢海宁<luhaining@myhexin.com>
 * @date: 2013-11-12
 */
var EltLog = Log.extend({});

/**
 * 浏览器控制台日志输出类
 * @author: 卢海宁<luhaining@myhexin.com>
 * @date: 2013-11-18
 */
var WebLog = Log.extend({

	init: function(cfg){
		this._super();
		try{
			if(!window.console){
				window.console = {
					log: function(){},
					error: function(){}
				};
			}
		}catch(e){}
	},

	log: function(info){
		if(!this.enable){
			return;
		}
		return Global.isIE6 ? alert(info) : console.log(info);
	},
	
	error: function(info){
		if(!this.enable){
			return;
		}
		return Global.isIE6 ? alert(info) : console.error(info);
	}
});